<?php

namespace Elementor;

if (!defined('ABSPATH')) exit;

class Qhost_Button extends Widget_Base
{

	/**
	 * Get widget name.
	 *
	 * Retrieve button widget name.
	 *
	 * @return string Widget name.
	 * @since 1.0.0
	 * @access public
	 *
	 */
	public function get_name()
	{
		return 'tt-button';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve button widget title.
	 *
	 * @return string Widget title.
	 * @since 1.0.0
	 * @access public
	 *
	 */
	public function get_title()
	{
		return __('Qhost Button', 'qhost-core');
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve button widget icon.
	 *
	 * @return string Widget icon.
	 * @since 1.0.0
	 * @access public
	 *
	 */
	public function get_icon()
	{
		return 'eicon-button';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the icon box widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * @return array Widget categories.
	 * @since 1.0.0
	 * @access public
	 *
	 */
	public function get_categories()
	{
		return ['tt-elements'];
	}

	/**
	 * Get button sizes.
	 *
	 * Retrieve an array of button sizes for the button widget.
	 *
	 * @return array An array containing button sizes.
	 * @since 1.0.0
	 * @access public
	 * @static
	 *
	 */
	public static function get_button_sizes()
	{
		return [
			'btn-xs' => __('Extra Small', 'qhost-core'),
			'btn-sm' => __('Small', 'qhost-core'),
			'btn-md' => __('Medium', 'qhost-core'),
			'btn-lg' => __('Large', 'qhost-core'),
			'btn-xl' => __('Extra Large', 'qhost-core'),
		];
	}

	/**
	 * Register button widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function _register_controls()
	{
		$this->start_controls_section(
			'section_button',
			[
				'label' => __('Button', 'qhost-core'),
			]
		);


		$this->add_control(
			'button_size',
			[
				'label' => __('Size', 'qhost-core'),
				'type' => Controls_Manager::SELECT,
				'default' => 'btn-md',
				'options' => $this->get_button_sizes(),
			
			]
		);

		$this->add_control(
			'button_shape',
			[
				'label' => __('Shape', 'qhost-core'),
				'type' => Controls_Manager::SELECT,
				'default' => 'btn-round',
				'options' => [
					'btn-square' => __('Square', 'qhost-core'),
					'btn-round' => __('Round', 'qhost-core'),
					'btn-circle' => __('Circle', 'qhost-core'),
				],
			]
		);

		$this->add_control(
			'button_style',
			[
				'label' => __('Shape', 'qhost-core'),
				'type' => Controls_Manager::SELECT,
				'default' => 'btn-default',
				'options' => [
					'btn-default' => __('Default', 'qhost-core'),
					'btn-outline' => __('Outline', 'qhost-core'),
				],
			]
		);

		$this->add_control(
			'text',
			[
				'label' => __('Text', 'qhost-core'),
				'type' => Controls_Manager::TEXT,
				'default' => __('Learn More', 'qhost-core'),
				'placeholder' => __('Button Text', 'qhost-core'),
			]
		);

		$this->add_control(
			'link',
			[
				'label' => __('Link', 'qhost-core'),
				'type' => Controls_Manager::URL,
				'placeholder' => 'http://your-link.com',
				'default' => [
					'url' => '#',
				],
			]
		);

		$this->add_control(
			'icon',
			[
				'label' => __('Icon', 'qhost-core'),
				'type' => Controls_Manager::ICON,
				'label_block' => true,
				'options' => qhost_themify_icons(),
				'include' => qhost_include_themify_icons(),
				'default' => '',
			]
		);

		$this->add_control(
			'icon_align',
			[
				'label' => __('Icon Position', 'qhost-core'),
				'type' => Controls_Manager::SELECT,
				'default' => 'left',
				'options' => [
					'left' => __('Before', 'qhost-core'),
					'right' => __('After', 'qhost-core'),
				],
				'condition' => [
					'icon!' => '',
				],
			]
		);

		$this->add_control(
			'icon_indent',
			[
				'label' => __('Icon Spacing', 'qhost-core'),
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'max' => 50,
					],
				],
				'condition' => [
					'icon!' => '',
				],
				'selectors' => [
					'{{WRAPPER}} .tt-btn .elementor-align-icon-right' => 'margin-left: {{SIZE}}{{UNIT}};',
					'{{WRAPPER}} .tt-btn .elementor-align-icon-left' => 'margin-right: {{SIZE}}{{UNIT}};',
				],
			]
		);

		$this->add_responsive_control(
			'align',
			[
				'label' => __('Alignment', 'qhost-core'),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => __('Left', 'qhost-core'),
						'icon' => 'fa fa-align-left',
					],
					'center' => [
						'title' => __('Center', 'qhost-core'),
						'icon' => 'fa fa-align-center',
					],
					'right' => [
						'title' => __('Right', 'qhost-core'),
						'icon' => 'fa fa-align-right',
					],
					'justify' => [
						'title' => __('Justified', 'qhost-core'),
						'icon' => 'fa fa-align-justify',
					],
				],
				'prefix_class' => 'elementor%s-align-',
				'default' => '',
			]
		);

		$this->add_control(
			'view',
			[
				'label' => __('View', 'qhost-core'),
				'type' => Controls_Manager::HIDDEN,
				'default' => 'traditional',
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_style',
			[
				'label' => __('Button', 'qhost-core'),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'typography',
				'label' => __('Typography', 'qhost-core'),
				'selector' => '{{WRAPPER}} a.tt-btn, {{WRAPPER}} .tt-btn',
			]
		);

		$this->start_controls_tabs('tabs_button_style');

		$this->start_controls_tab(
			'tab_button_normal',
			[
				'label' => __('Normal', 'qhost-core'),
			]
		);

		$this->add_control(
			'button_text_color',
			[
				'label' => __('Text Color', 'qhost-core'),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} a.tt-btn, {{WRAPPER}} .tt-btn' => 'color: {{VALUE}};',
				],
			]
        );

		  $this->add_control(
			'background__color',
			[
				'label' => __('Background Color', 'qhost-core'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .tt-btn' => 'background: {{VALUE}};',
				],
			]
		);
        
        $this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'border',
				'label' => __('Border', 'qhost-core'),
				'placeholder' => '1px',
				'default' => '1px',
				'selector' => '{{WRAPPER}} .tt-btn',
				'separator' => 'before',
			]
		);	

		$this->add_group_control(
			\Elementor\Group_Control_Box_Shadow::get_type(),
			[
				'name' => 'btn_box_shadow',
				'label' => __( 'Box Shadow', 'qhost-core' ),
				'selector' => '{{WRAPPER}} .tt-btn',
			]
		);

		$this->end_controls_tab();

		$this->start_controls_tab(
			'tab_button_hover',
			[
				'label' => __('Hover', 'qhost-core'),
			]
		);

		$this->add_control(
			'hover_color',
			[
				'label' => __('Text Color', 'qhost-core'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .tt-btn:hover, {{WRAPPER}} .tt-btn:hover' => 'color: {{VALUE}};',
				],
			]
        );
        
        $this->add_control(
			'background__hover_color',
			[
				'label' => __('Background Color', 'qhost-core'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .tt-btn:hover' => 'background: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'border_hover',
				'label' => __('Border', 'qhost-core'),
				'placeholder' => '1px',
				'default' => '1px',
				'selector' => '{{WRAPPER}} .tt-btn:hover',
				'separator' => 'before',
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Box_Shadow::get_type(),
			[
				'name' => 'btn_hover_box_shadow',
				'label' => __( 'Box Shadow', 'qhost-core' ),
				'selector' => '{{WRAPPER}} .tt-btn:hover',
			]
		);


		$this->end_controls_tab();

		$this->end_controls_tabs();

	

		$this->add_control(
			'border_radius',
			[
				'label' => __('Border Radius', 'qhost-core'),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => ['px', '%'],
				'selectors' => [
					'{{WRAPPER}} a.tt-btn, {{WRAPPER}} .tt-btn' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);


		$this->add_control(
			'text_padding',
			[
				'label' => __('Text Padding', 'qhost-core'),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => ['px', 'em', '%'],
				'selectors' => [
					'{{WRAPPER}} a.tt-btn, {{WRAPPER}} .tt-btn' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
				'separator' => 'before',
			]
		);

		$this->end_controls_section();
	}

	/**
	 * Render button widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function render()
	{
		$settings = $this->get_settings_for_display();
		$button_type = $settings['button_size'];

		$this->add_render_attribute('wrapper', 'class', 'tt-btn-wrapper');

		if (!empty($settings['link']['url'])) {
			$this->add_render_attribute('button', 'href', $settings['link']['url']);
			$this->add_render_attribute('button', 'class', 'tt-btn-link');

			if ($settings['link']['is_external']) {
				$this->add_render_attribute('button', 'target', '_blank');
			}

			if ($settings['link']['nofollow']) {
				$this->add_render_attribute('button', 'rel', 'nofollow');
			}
		}

		$this->add_render_attribute('button', 'class', 'tt-btn');


		if (!empty($settings['button_shape'])) {
			$this->add_render_attribute('button', 'class', $settings['button_shape']);
		}

		if (!empty($settings['button_size'])) {
			$this->add_render_attribute('button', 'class', $settings['button_size']);
		}
		if (!empty($settings['button_style'])) {
			$this->add_render_attribute('button', 'class', $settings['button_style']);
		}	

		?>
        <div <?php echo $this->get_render_attribute_string('wrapper'); ?>>
            <a <?php echo $this->get_render_attribute_string('button'); ?>>
				<?php $this->render_text(); ?>
            </a>
        </div>
		<?php
	}

	/**
	 * Render button widget output in the editor.
	 *
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function _content_template() {
		?>
        <#
        view.addRenderAttribute( 'text', 'class', 'btn-text' );

        view.addInlineEditingAttributes( 'text', 'none' );
        #>
        <div class="tt-btn-wrapper">

            <a class="tt-btn {{ settings.button_shape }} {{ settings.button_size }} {{ settings.button_style }} elementor-animation-{{ settings.hover_animation }}"
               href="{{ settings.link.url }}">
				<span class="tt-btn-content-wrapper">
					<# if ( settings.icon ) { #>
					<span class="tt-btn-icon elementor-align-icon-{{ settings.icon_align }}">
						<i class="{{ settings.icon }}" aria-hidden="true"></i>
					</span>
					<# } #>
					<span {{{ view.getRenderAttributeString( 'text' ) }}}>{{{ settings.text }}}</span>
                </span>
            </a>

        </div>
		<?php
	}

	/**
	 * Render button text.
	 *
	 * Render button widget text.
	 *
	 * @since 1.5.0
	 * @access protected
	 */
	protected function render_text() {
		$settings = $this->get_settings();
		$this->add_render_attribute('content-wrapper', 'class', 'tt-btn-content-wrapper');
		$this->add_render_attribute('icon-align', 'class', 'elementor-align-icon-' . $settings['icon_align']);
		$this->add_render_attribute('icon-align', 'class', 'tt-btn-icon');

		$this->add_render_attribute('text', 'class', 'tt-btn-text');

		// $this->add_inline_editing_attributes( 'text', 'none' );
		?>
        <span <?php echo $this->get_render_attribute_string('content-wrapper'); ?>>
			<?php if (!empty($settings['icon'])) : ?>
                <span <?php echo $this->get_render_attribute_string('icon-align'); ?>>
					<i class="<?php echo esc_attr($settings['icon']); ?>" aria-hidden="true"></i>
				</span>
			<?php endif; ?>
			<span <?php echo $this->get_render_attribute_string('text'); ?>><?php echo $settings['text']; ?></span>
		</span>
		<?php
	}
}