<?php
/**
 * Plugin Name: Qhost Core
 * Plugin URI: https://themeforest.net/user/themetags/portfolio
 * Description: This plugin adds the core features to the Qhost WordPress theme. You must have to install this plugin to get all the features included with the theme.
 * Version: 1.0.0
 * Author: ThemeTags
 * Author URI: https://themeforest.net/user/themetags/portfolio
 * Text domain: qhost-core
 */

if (!defined('ABSPATH'))
	die('-1');


/**
 * Currently plugin version.
 * Start at version 1.0.0 and use SemVer - https://semver.org
 * Rename this for your plugin and update it as you release new versions.
 */
define('QHOST_CORE_VERSION', '1.0.0');

/**
 * Constant for the plugins
 */
define('QHOST_PLUGIN_URL', plugins_url() . '/qhost-core/');
define('QHOST_PLUGIN_ASSETS_URL', plugins_url() . '/qhost-core/assets/');
define('QHOST_ADDONCE_DIR', plugin_dir_path( __FILE__ ));
define('QHOST_SCRIPTS', QHOST_PLUGIN_URL . 'assets/js' );


// Make sure the same class is not loaded twice in free/premium versions.
if (!class_exists('Qhost_Core')) {
	/**
	 * Main Qhost Core Class
	 *
	 * The main class that initiates and runs the Qhost Core plugin.
	 *
	 * @since 1.0.0
	 */
	final class Qhost_Core {
		/**
		 * Qhost Core Version
		 *
		 * Holds the version of the plugin.
		 *
		 * @since 1.0.0
		 * 
		 * @var string The plugin version.
		 */
		const VERSION = '1.0';

		/**
		 * Minimum Elementor Version
		 *
		 * Holds the Minimum Elementor version required to run the plugin.
		 *
		 * @since 1.0.0
		 * 
		 * @var string Minimum Elementor version required to run the plugin.
		 */
		const MINIMUM_ELEMENTOR_VERSION = '2.0.0';

		/**
		 * Minimum PHP Version
		 *
		 * Holds the minimum PHP version required to run the plugin.
		 *
		 * @since 2.0.0
		 * 
		 * @var string Minimum PHP version required to run the plugin.
		 */
		const  MINIMUM_PHP_VERSION = '5.6';
		


		/**
		 * Instance
		 *
		 * Holds a single instance of the `Qhost_Core` class.
		 *
		 * @since 1.0.0
		 *
		 * @access private
		 * @static
		 *
		 * @var Qhost_Core A single instance of the class.
		 */
		private static $_instance = null;

		/**
		 * The loader that's responsible for maintaining and registering all hooks that power
		 * the plugin.
		 *
		 * @since    1.0.0
		 * @access   protected
		 * @var      Qhost_Core    $loader    Maintains and registers all hooks for the plugin.
		 */
		protected $loader;

		/**
		 * Instance
		 *
		 * Ensures only one instance of the class is loaded or can be loaded.
		 *
		 * @return Qhost_Core An instance of the class.
		 * @since 1.0.0
		 *
		 * @access public
		 * @static
		 *
		 */
		public static function instance() {
			if (is_null(self::$_instance)) {
				self::$_instance = new self();
			}

			return self::$_instance;
		}

		/**
		 * Clone
		 *
		 * Disable class cloning.
		 *
		 * @return void
		 * @since 1.0.0
		 *
		 * @access protected
		 *
		 */
		public function __clone() {
			// Cloning instances of the class is forbidden
			_doing_it_wrong(__FUNCTION__, esc_html__('Cheatin&#8217; huh?', 'qhost-core'), '2.0.0');
		}

		/**
		 * Wakeup
		 *
		 * Disable unserializing the class.
		 *
		 * @return void
		 * @since 1.0.0
		 *
		 * @access protected
		 *
		 */
		public function __wakeup() {
			// Unserializing instances of the class is forbidden.
			_doing_it_wrong(__FUNCTION__, esc_html__('Cheatin&#8217; huh?', 'qhost-core'), '2.0.0');
		}

		/**
		 * Constructor
		 *
		 * Initialize the Qhost Core plugins.
		 *
		 * @since 1.0.0
		 *
		 * @access public
		 */
		public function __construct() {
			$this->core_includes();
			$this->init_hooks();
			add_action( 'after_switch_theme', [ $this, 'add_cpt_support' ] );
			do_action('qhost_core_loaded');

		}

		/**
		 * Include Files
		 *
		 * Load core files required to run the plugin.
		 *
		 * @since 1.0.0
		 *
		 * @access public
		 */
		public function core_includes()	{
			// Extra
			require_once __DIR__ . '/inc/mailchimp.php';
			require_once __DIR__ . '/inc/extra.php';
			require_once __DIR__ . '/inc/domain.php';

			// Mega Menu
			require_once __DIR__ . '/inc/post-type/class-header.php';

			//Elementor Widgets
			require_once __DIR__ . '/modules/class-widget-init.php';

			// Elementor custom field icons
			require_once __DIR__ . '/modules/fields/icons.php';

			// Demo Importer
			require_once __DIR__ . '/inc/demo-settings.php';
		}

		/**
		 * Init Hooks
		 *
		 * Hook into actions and filters.
		 *
		 * @since 1.0.0
		 *
		 * @access private
		 */
		private function init_hooks() {
			add_action('init', [$this, 'i18n']);
			add_action('plugins_loaded', [$this, 'init']);
		}

		/**
		 * Load Textdomain
		 *
		 * Load plugin localization files.
		 *
		 * @since 1.0.0
		 *
		 * @access public
		 */
		public function i18n() {
			load_plugin_textdomain('qhost-core', false, plugin_basename(dirname(__FILE__)) . '/languages');
		}

		/**
		 * Init Qhost Core
		 *
		 * Load the plugin after Elementor (and other plugins) are loaded.
		 *
		 * @since 1.0.0
		 * @since 2.0.0 The logic moved from a standalone function to this class method.
		 *
		 * @access public
		 */
		public function init() {

			if (!did_action('elementor/loaded')) {
				add_action('admin_notices', [$this, 'admin_notice_missing_main_plugin']);
				return;
			}

			// Check for required Elementor version
			if (!version_compare(ELEMENTOR_VERSION, self::MINIMUM_ELEMENTOR_VERSION, '>=')) {
				add_action('admin_notices', [$this, 'admin_notice_minimum_elementor_version']);
				return;
			}

			// Check for required PHP version
			if (version_compare(PHP_VERSION, self::MINIMUM_PHP_VERSION, '<')) {
				add_action('admin_notices', [$this, 'admin_notice_minimum_php_version']);
				return;
			}

			// Register Widget Scripts
			add_action('elementor/frontend/after_enqueue_styles', [$this, 'enqueue_widget_styles']);
			add_action('elementor/editor/before_enqueue_scripts', [$this, 'enqueue_widget_styles']);
			add_action('wp_enqueue_scripts', [$this, 'qhost_dequeue'], 100);

		}

		/**
		 * Admin notice
		 *
		 * Warning when the site doesn't have Elementor installed or activated.
		 *
		 * @since 1.1.0
		 * @since 2.0.0 Moved from a standalone function to a class method.
		 *
		 * @access public
		 */
		public function admin_notice_missing_main_plugin() {
			$message = sprintf(
			/* translators: 1: Qhost Core 2: Elementor */
				esc_html__('"%1$s" requires "%2$s" to be installed and activated.', 'qhost-core'),
				'<strong>' . esc_html__('Qhost Core', 'qhost-core') . '</strong>',
				'<strong>' . esc_html__('Elementor', 'qhost-core') . '</strong>'
			);
			printf('<div class="notice notice-warning is-dismissible"><p>%1$s</p></div>', $message);
		}

		/**
		 * Admin notice
		 *
		 * Warning when the site doesn't have a minimum required Elementor version.
		 *
		 * @since 1.1.0
		 * @since 2.0.0 Moved from a standalone function to a class method.
		 *
		 * @access public
		 */
		public function admin_notice_minimum_elementor_version() {
			$message = sprintf(
			/* translators: 1: Qhost Core 2: Elementor 3: Required Elementor version */
				esc_html__('"%1$s" requires "%2$s" version %3$s or greater.', 'qhost-core'),
				'<strong>' . esc_html__('Qhost Core', 'qhost-core') . '</strong>',
				'<strong>' . esc_html__('Elementor', 'qhost-core') . '</strong>',
				self::MINIMUM_ELEMENTOR_VERSION
			);
			printf('<div class="notice notice-warning is-dismissible"><p>%1$s</p></div>', $message);
		}

		/**
		 * Admin notice
		 *
		 * Warning when the site doesn't have a minimum required PHP version.
		 *
		 * @since 2.0.0
		 *
		 * @access public
		 */
		public function admin_notice_minimum_php_version() {
			$message = sprintf(
			/* translators: 1: Qhost Core 2: PHP 3: Required PHP version */
				esc_html__('"%1$s" requires "%2$s" version %3$s or greater.', 'qhost-core'),
				'<strong>' . esc_html__('Qhost Elements', 'qhost-core') . '</strong>',
				'<strong>' . esc_html__('PHP', 'qhost-core') . '</strong>',
				self::MINIMUM_PHP_VERSION
			);
			printf('<div class="notice notice-warning is-dismissible"><p>%1$s</p></div>', $message);
		}	

		/**
		 * Register Widget Styles
		 *
		 * Register custom styles required to run Qhost Core.
		 *
		 * @since 2.0.0
		 * @since 1.7.1 The method moved to this class.
		 *
		 * @access public
		 */

		public function enqueue_widget_styles()	{		
			wp_enqueue_style('themify-icons', plugins_url('assets/vendors/themify-icon/themify-icons.css', __FILE__));		
			wp_enqueue_style('elegant-icons', plugins_url('assets/vendors/components-elegant-icons/css/elegant-icons.min.css', __FILE__));
			wp_enqueue_style('flaticon', plugins_url('assets/vendors/components-elegant-icons/css/elegant-icons.min.css', __FILE__));
		}

		/**
		 * Dequeue the Elementor Animation CSS.
		 *
		 * Hooked to the wp_print_scripts action, with a late priority (100),
		 * so that it is after the script was enqueued.
		 */

		function qhost_dequeue() {
			wp_dequeue_style('elementor-animations');
			wp_deregister_style('elementor-animations');
//			wp_dequeue_style('font-awesome-css');
//			wp_deregister_style('font-awesome-css');
		}

	}
}
// Make sure the same function is not loaded twice in free/premium versions.

if (!function_exists('qhost_core_load')) {
	/**
	 * Load Qhost Core
	 *
	 * Main instance of Qhost_Core.
	 *
	 * @since 1.0.0
	 * @since 2.0.0 The logic moved from this function to a class method.
	 */
	function qhost_core_load()	{
		return Qhost_Core::instance();
	}

	// Run Qhost Core
	qhost_core_load();
}